Update the data of a pie chart in a Shiny app.
updateAmPieChart(session, outputId, data)the Shiny session object
the output id passed on to amChart4Output
new data; if it is not valid, then nothing will happen (in order
to be valid it must have the same structure as the data passed on to
amPieChart); in this case check the JavaScript console, it
will report the encountered issue